AliAuthPluginWeb class

Web implementation of AliAuthPlatform.

Inheritance

Constructors

AliAuthPluginWeb({AliAuthPluginWebApi? api})

Properties

appleLogin → Future?
no setterinherited
checkCellularDataEnable → Future?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkAuthAvailable(String accessToken, String jwtToken, void success(dynamic), void error(dynamic)) → Future<void>
Web only: checks whether number authentication is available.
override
checkEnvAvailable() → Future<void>
inherited
dispose() → void
inherited
getConnection() → Future<String?>
override
getCurrentCarrierName() → Future<String>
inherited
getPlatformVersion() → Future<String?>
override
getSdkVersion() → Future<String?>
override
getVerifyToken(void success(dynamic), void error(dynamic)) → Future<void>
Web only: gets a local-number verification token after authentication.
override
hideLoading() → Future<void>
inherited
initSdk(AliAuthModel? config) → Future
inherited
login({int timeout = 5000}) → Future
inherited
loginListen({bool type = true, required Function onEvent, Function? onError, dynamic isOnlyOne = true}) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onChange({bool type = true}) → Stream?
inherited
openPage(String? pageRoute) → Future<void>
inherited
pause() → void
inherited
queryCheckBoxIsChecked() → Future<void>
inherited
quitPage() → Future<void>
inherited
resume() → void
inherited
setCheckboxIsChecked() → Future<void>
inherited
setLoggerEnable(bool isEnable) → Future<void>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

registerWith(Registrar registrar) → void